@@ -1,5 +1,5 @@
 """
-This package holds the abstraction libraries for 1 wire.
+A light layer to use OWFS and pyownet with a more OOP approach.
 """
 import importlib
 import logging
@@ -17,9 +17,10 @@ from .exc import UnrecognizedDeviceError
 
 class OwClient:
     """
-    An OWFS abstraction layer
+    The main class to use OwClient
 
-    A light layer to use OWFS and pyownet with a more OOP approach.
+    This class allows you to list the devices connected to the bus and load
+    them for easy access.
 
     Parameters
     ----------
@@ -32,6 +33,33 @@ class OwClient:
     unchached: bool, optional:
         (Default value = True)
         Ignore the owfs server cache.
+
+    Examples
+    --------
+    Connect to local owserver and get a list of devices
+    >>> from owclient import OwClient
+    ... owc = OwClient()
+    ... owc.devices
+    (<DS18B20(path=/28.67C6697351FF/, query_path=uncached/28.67C6697351FF/,
+    uncached=True, address=2867C6697351FF68, r_address=68FF517369C66728,
+    crc8=68, family=28, id=67C6697351FF, r_id=FF517369C667,
+    locator=ajrhwgbkmnnzkmaj, r_locator=xgxeaoyhklptgoti, temperature=60.1196,
+    power=True, temperature9=47.0094, temperature10=2.83714,
+    temperature11=59.8101, temperature12=4.34243, fasttemp=70.0092,
+    temphigh=80, templow=29)>, <DS18B20(path=/28.4AEC29CDBAAB/,
+    query_path=uncached/28.4AEC29CDBAAB/, uncached=True,
+    address=284AEC29CDBAAB95, r_address=95ABBACD29EC4A28, crc8=95, family=28,
+    id=4AEC29CDBAAB, r_id=ABBACD29EC4A, locator=uesiebgkymmoltyw,
+    r_locator=kteymmxwbtpuysbv, temperature=9.66286, power=True,
+    temperature9=16.221, temperature10=57.1401, temperature11=29.6303,
+    temperature12=5.68529, fasttemp=9.70614, temphigh=90, templow=10)>,
+    <DS18B20(path=/28.F2FBE3467CC2/, query_path=uncached/28.F2FBE3467CC2/,
+    uncached=True, address=28F2FBE3467CC278, r_address=78C27C46E3FBF228,
+    crc8=78, family=28, id=F2FBE3467CC2, r_id=C27C46E3FBF2,
+    locator=aijtgfdzmenybkau, r_locator=zwvtxqrrtvnfjidj, temperature=7.1848,
+    power=True, temperature9=5.75829, temperature10=93.8447,
+    temperature11=29.8333, temperature12=90.8721, fasttemp=84.5132,
+    temphigh=33, templow=27)>)
     """
     def __init__(self,
                  host: str = 'localhost',
@@ -123,9 +151,9 @@ class OwClient:
             device_module = importlib.import_module(
                 f'owclient.devices.{device_type.lower()}')
             device_class = getattr(device_module, device_type.upper())
-            result = device_class(proxy, path, self.uncached)
-            self.logger.debug(f'Device class loaded: {result.__class__}')
-            return result
+            device = device_class(proxy, path, self.uncached)
+            self.logger.debug(f'Device class loaded: {type(device)}')
+            return device
         except pyownet.protocol.OwnetError as ex:
             error_message = f'Could not load device at path {path}.'
             self.logger.exception(error_message)
@@ -173,5 +201,5 @@ class OwClient:
             raise CouldNotLoadDevicesError(error_message) from ex
 
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 __all__ = ['OwClient']
